Release History
---------------

**0.0.4 (2022-7-21)**

- public python-docx-oss docs @ readthedocs.
- add delete_item in CustomXmlPart. #17


**0.0.3 (2022-7-01)**

- Change method text to texts in CT_R. #14
- Add external target_ref setter. #15
- Blacken all Python files.


**0.0.2 (2022-06-24)**

- Add custom xml support. #10
- Add Part __eq__.
- Add Part element setter. 
- Add Relationships parts_with_reltype.


**0.0.1 (2022-06-16)**

- Only support Python3.8, 3.9 and 3.10.
- Add custom properties support. #2
- Add drop_rels in Package. #5
- Add drop_rels in Part. #5
- Add default NumberingPart. #4
- Fix Python3.8+ __dict__ TypeError. #6
- Add some typehint.
